@@ -37,7 +37,7 @@ except ImportError:
 from reportlab.platypus.paraparser import ParaFrag, ps2tt, tt2ps
 
 from xhtml2pdf import default, parser
-from xhtml2pdf.files import getFile, pisaFileObject
+from xhtml2pdf.files import B64InlineURI, getFile, pisaFileObject
 from xhtml2pdf.tables import TableData
 from xhtml2pdf.util import (
     arabic_format,
@@ -199,14 +199,14 @@ class pisaCSSBuilder(css.CSSBuilder):
 
         # Font weight
         fweight = str(data.get("font-weight", "normal")).lower()
-        bold = fweight in ("bold", "bolder", "500", "600", "700", "800", "900")
+        bold = fweight in {"bold", "bolder", "500", "600", "700", "800", "900"}
         if not bold and fweight != "normal":
             log.warning(
                 self.c.warning("@fontface, unknown value font-weight '%s'", fweight)
             )
 
         # Font style
-        italic = str(data.get("font-style", "")).lower() in ("italic", "oblique")
+        italic = str(data.get("font-style", "")).lower() in {"italic", "oblique"}
 
         # The "src" attribute can be a CSS group but in that case
         # ignore everything except the font URI
@@ -1084,13 +1084,22 @@ class pisaContext:
 
             # XXX Problems with unicode here
             fontAlias = [str(x) for x in fontAlias]
-
             fontName = fontAlias[0]
-            parts = src.split(".")
-            baseName, suffix = ".".join(parts[:-1]), parts[-1]
-            suffix = suffix.lower()
 
-            if suffix in ["ttc", "ttf"]:
+            font_type = None
+            if isinstance(file.instance, B64InlineURI):
+                if file.getMimeType() == "font/ttf":
+                    font_type = "ttf"
+            else:
+                parts = src.split(".")
+                baseName, suffix = ".".join(parts[:-1]), parts[-1]
+                suffix = suffix.lower()
+                if suffix in ("ttf", "ttc"):
+                    font_type = "ttf"
+                elif suffix in ("afm", "pfb"):
+                    font_type = suffix
+
+            if font_type == "ttf":
                 # determine full font name according to weight and style
                 fullFontName = "%s_%d%d" % (fontName, bold, italic)
 
@@ -1118,8 +1127,8 @@ class pisaContext:
                     # Register "normal" name and the place holder for style
                     self.registerFont(fontName, [*fontAlias, fullFontName])
 
-            elif suffix in ("afm", "pfb"):
-                if suffix == "afm":
+            elif font_type in ("afm", ""):
+                if font_type == "afm":
                     afm = file.getNamedFile()
                     tfile = pisaFileObject(baseName + ".pfb", basepath=file.basepath)
                     pfb = tfile.getNamedFile()
