@@ -14,7 +14,7 @@ The CSS 2.1 Specification this parser was derived from can be found at http://ww
 Primary Classes:
     * CSSParser
         Parses CSS source forms into results using a Builder Pattern.  Must
-        provide concrete implemenation of CSSBuilderAbstract.
+        provide concrete implementation of CSSBuilderAbstract.
 
     * CSSBuilderAbstract
         Outlines the interface between CSSParser and it's rule-builder.
@@ -389,7 +389,7 @@ class CSSParser:
     # XXX For now
     # i_uri = '(url\\(.*?\\))'
     re_uri = re.compile(i_uri, _reflags)
-    i_num = (  # XXX Added out paranthesis, because e.g. .5em was not parsed correctly
+    i_num = (  # XXX Added out parenthesis, because e.g. .5em was not parsed correctly
         r"(([-+]?[0-9]+(?:\.[0-9]+)?)|([-+]?\.[0-9]+))"
     )
     re_num = re.compile(i_num, _reflags)
@@ -439,7 +439,7 @@ class CSSParser:
         Parses CSS file-like objects using the current cssBuilder.
         Use for external stylesheets.
         """
-        with open(srcFile) as file_handler:
+        with open(srcFile, encoding="utf-8") as file_handler:
             file_content = file_handler.read()
 
         return self.parse(file_content)
@@ -466,7 +466,7 @@ class CSSParser:
     def parseInline(self, src):
         """
         Parses CSS inline source string using the current cssBuilder.
-        Use to parse a tag's 'sytle'-like attribute.
+        Use to parse a tag's 'style'-like attribute.
         """
         self.cssBuilder.beginInline()
         try:
@@ -707,7 +707,7 @@ class CSSParser:
         while src and src[0] != "{":
             medium, src = self._getIdent(src)
             # make "and ... {" work
-            if medium in (None, "and"):
+            if medium in {None, "and"}:
                 # default to mediatype "all"
                 if medium is None:
                     mediums.append("all")
@@ -924,7 +924,7 @@ class CSSParser:
 
     def _parseSelectorGroup(self, src):
         selectors = []
-        while src[:1] not in ("{", "}", "]", "(", ")", ";", ""):
+        while src[:1] not in {"{", "}", "]", "(", ")", ";", ""}:
             src, selector = self._parseSelector(src)
             if selector is None:
                 break
@@ -941,7 +941,7 @@ class CSSParser:
         """
         src, selector = self._parseSimpleSelector(src)
         srcLen = len(src)  # XXX
-        while src[:1] not in ("", ",", ";", "{", "}", "[", "]", "(", ")"):
+        while src[:1] not in {"", ",", ";", "{", "}", "[", "]", "(", ")"}:
             for combiner in self.SelectorCombiners:
                 if src.startswith(combiner):
                     src = src[len(combiner) :].lstrip()
@@ -950,11 +950,11 @@ class CSSParser:
                 combiner = " "
             src, selectorB = self._parseSimpleSelector(src)
 
-            # XXX Fix a bug that occured here e.g. : .1 {...}
+            # XXX Fix a bug that occurred here e.g. : .1 {...}
             if len(src) >= srcLen:
                 src = src[1:]
                 while src and (
-                    src[:1] not in ("", ",", ";", "{", "}", "[", "]", "(", ")")
+                    src[:1] not in {"", ",", ";", "{", "}", "[", "]", "(", ")"}
                 ):
                     src = src[1:]
                 return src.lstrip(), None
@@ -1097,7 +1097,7 @@ class CSSParser:
 
         properties = []
         src = src.lstrip()
-        while src[:1] not in ("", ",", "{", "}", "[", "]", "(", ")", "@"):  # XXX @?
+        while src[:1] not in {"", ",", "{", "}", "[", "]", "(", ")", "@"}:  # XXX @?
             src, single_property = self._parseDeclaration(src)
 
             # XXX Workaround for styles like "*font: smaller"
@@ -1135,10 +1135,10 @@ class CSSParser:
         if property_name is not None:
             src = src.lstrip()
             # S* : S*
-            if src[:1] in (":", "="):
-                # Note: we are being fairly flexable here...  technically, the
+            if src[:1] in {":", "="}:
+                # Note: we are being fairly flexible here...  technically, the
                 # ":" is *required*, but in the name of flexibility we
-                # suppor a null transition, as well as an "=" transition
+                # support a null transition, as well as an "=" transition
                 src = src[1:].lstrip()
 
             src, single_property = self._parseDeclarationProperty(src, property_name)
@@ -1168,7 +1168,7 @@ class CSSParser:
         """
         src, term = self._parseExpressionTerm(src)
         operator = None
-        while src[:1] not in ("", ";", "{", "}", "[", "]", ")"):
+        while src[:1] not in {"", ";", "{", "}", "[", "]", ")"}:
             for operator in self.ExpressionOperators:
                 if src.startswith(operator):
                     src = src[len(operator) :]
