@@ -302,7 +302,7 @@ class PmlImageReader:  # TODO We need a factory here, returning either a class f
         if isinstance(fileName, PmlImage):
             self.__dict__ = fileName.__dict__  # borgize
             return
-            # start wih lots of null private fields, to be populated by
+            # start with lots of null private fields, to be populated by
         # the relevant engine.
         self.fileName: PmlImage | Image | str = fileName or f"PILIMAGE_{id(self)}"
         self._image: Image = None
@@ -421,7 +421,7 @@ class PmlImageReader:  # TODO We need a factory here, returning either a class f
                     self._dataA = PmlImageReader(im.split()[3])
                     im = im.convert("RGB")
                     self.mode = "RGB"
-                elif mode not in ("L", "RGB", "CMYK"):
+                elif mode not in {"L", "RGB", "CMYK"}:
                     im = im.convert("RGB")
                     self.mode = "RGB"
                 self._data = im.tobytes() if hasattr(im, "tobytes") else im.tostring()
@@ -520,7 +520,7 @@ class PmlImage(Flowable, PmlMaxHeightMixIn):
         factor = min(wfactor, hfactor)
         self.dWidth = self.drawWidth * factor
         self.dHeight = self.drawHeight * factor
-        # print "imgage result", factor, self.dWidth, self.dHeight
+        # print "image result", factor, self.dWidth, self.dHeight
         return self.dWidth, self.dHeight
 
     def getDrawing(
@@ -641,7 +641,7 @@ class PmlParagraph(Paragraph, PmlMaxHeightMixIn):
         availWidth -= self.deltaWidth
         availHeight -= self.deltaHeight
 
-        # Modify maxium image sizes
+        # Modify maximum image sizes
         self._calcImageMaxSizes(availWidth, availHeight)
 
         # call the base class to do wrapping and calculate the size
@@ -651,8 +651,8 @@ class PmlParagraph(Paragraph, PmlMaxHeightMixIn):
         # self.width = max(1, self.width)
 
         # increase the calculated size by the padding
-        self.width = self.width + self.deltaWidth
-        self.height = self.height + self.deltaHeight
+        self.width += self.deltaWidth
+        self.height += self.deltaHeight
 
         return self.width, self.height
 
@@ -848,7 +848,7 @@ class PmlTable(Table, PmlMaxHeightMixIn):
         if sum(newColWidths) > totalWidth:
             quotient = totalWidth / sum(newColWidths)
             for i in range(len(newColWidths)):
-                newColWidths[i] = newColWidths[i] * quotient
+                newColWidths[i] *= quotient
 
         # To avoid rounding errors adjust one col with the difference
         diff = sum(newColWidths) - totalWidth
